//
// Data received via virtualwire and 433MHZ
// Receiver connected to pin 9
#include <VirtualWire.h>
#include <VirtualWire_Config.h>
#include <Accents.h>

int RX_PIN = 11;
int RX_ID = 3;

void setup() {
  Serial.begin(9600);
  // Virtualwire setup
  vw_set_rx_pin(RX_PIN); // RX pin set to pin 9
  vw_setup(2000); //sets virtualwire for a tx rate of 300 bits per second, nice and slow!
  vw_rx_start();
  pinMode(13, OUTPUT);
}
void loop() {
  typedef struct rxRemoteData //Defines the received data, this is the same as the TX struct
  {
    int TX_ID;
    float Temp;
    float Humidity;
    float Dew;
    int Error;
  };

  struct rxRemoteData receivedData;
  uint8_t rcvdSize = sizeof(receivedData);

  if (vw_have_message()) {
   if (vw_get_message((uint8_t *)&receivedData, &rcvdSize))
    {
      if (receivedData.TX_ID == RX_ID)     { //Only if the TX_ID=RX_ID do we process the data.
        digitalWrite(13, 1);
        Serial.println("Data received");
        float Temp = receivedData.Temp;
        float Humidity = receivedData.Humidity;
        float Dew = receivedData.Dew;
        int Error = receivedData.Error;
        if (Error > -1) {
          // writes the received data to the LCD
          Serial.print("Temp");
          Serial.print(Accents.Transcoder_UNICODE("é"));
          Serial.print("rature: ");
          Serial.print(Temp, 1);
          Serial.print((char)186);
          Serial.println("C");
          Serial.print("Humidit");
          Serial.print(Accents.Transcoder_UNICODE("é"));
          Serial.print(": ");
          Serial.print(Humidity, 1);
          Serial.println("%");
          Serial.print("Point ce ros");
          Serial.print(Accents.Transcoder_UNICODE("é"));
          Serial.print(": ");
          Serial.print(Dew, 1);
          Serial.print((char)186);
          Serial.println("C");
        } else {
          switch (Error) {
            case -1:
              Serial.print("Erreur transmise :");
              Serial.println("Error\n\r\tChecksum error");
              break;
            case -2:
              Serial.print("Erreur transmise :");
              Serial.println("Error\n\r\tTime out error");
              break;
            case -3:
              Serial.print("Erreur transmise :");
              Serial.println("Error\n\r\tAcquiring");
              break;
            case -4:
              Serial.print("Erreur transmise :");
              Serial.println("Error\n\r\tDelta time to small");
              break;
            case -5:
              Serial.print("Erreur transmise :");
              Serial.println("Error\n\r\tNot started");
              break;
          }
        }
        digitalWrite(13, 0);
        delay(1000);
      }
    }
  }
}
// End of file
