//
// PURPOSE: DHT11 sensor, idDHT library.
// Data send via virtualwire and 433MHZ
// DHT11 sensor is connected to 2
// TX connected to pin 10
/*
   Board	  int.0	  int.1	  int.2	  int.3	  int.4	  int.5
 Uno, Ethernet	  2	  3
 Mega2560	  2	  3	  21	  20	  19	  18
 Leonardo	  3	  2	  0	  1
 Due	          (any pin, more info http://arduino.cc/en/Reference/AttachInterrupt)
 */
#include <VirtualWire.h>
#include <VirtualWire_Config.h>
#include <idDHT11.h>

// define constants & global variables
int idDHT11pin = 2;        //Digital pin for comunications
int idDHT11intNumber = 0;  //interrupt number (must be the one that use the previus defined pin (see table above)
void dht11_wrapper();      // must be declared before the lib initialization
boolean OutputStatus = false; //Output status is off as default
int TX_PIN = 10;
int TX_ID = 3;

// Data structure set up for Transmission
typedef struct TXData
{
  int TX_ID;
  float Temp;
  float Humidity;
  float Dew;
};

typedef struct TXERRData
{
  int TX_ID;
  int Error;
};

// Lib instantiate
idDHT11 DHT11(idDHT11pin, idDHT11intNumber, dht11_wrapper);

void setup()
{
  // Virtualwire setup
  vw_set_tx_pin(TX_PIN); // TX pin set to 10
  vw_setup(2000); //sets virtualwire for a tx rate of 300 bits per second
  delay(1000); //Wait 1000ms recommended delay before accessing sensor
}

// This wrapper is in charge of calling
// mus be defined like this for the lib work
void dht11_wrapper() {
  DHT11.isrCallback();
}

void loop()
{
  DHT11.acquire();
  while (DHT11.acquiring());
  int result = DHT11.getStatus();
  if (!result) {
    // Read and store Sensor Data
    float Temp = DHT11.getCelsius();
    float Humidity = DHT11.getHumidity();
    float Dew = DHT11.getDewPoint();
  
    struct TXData payload; //Loads the Data struct with the payload data
    payload.TX_ID = TX_ID;
    payload.Temp = Temp;
    payload.Humidity = Humidity;
    payload.Dew = Dew;
  
    vw_send((uint8_t *)&payload, sizeof(payload)); //Transmits the struct
    vw_wait_tx(); //waits for the TX to complete
  } else {
    struct TXERRData ErrorPayload; //Loads the Data struct with the ErrPayload data
    ErrorPayload.TX_ID = TX_ID;
    ErrorPayload.Error = result;
    vw_send((uint8_t *)&ErrorPayload, sizeof(ErrorPayload)); //Transmits the struct
    vw_wait_tx(); //waits for the TX to complete
  }
}
// END OF FILE
